@@ -11,4 +11,6 @@ def test_class_properties():
 
 def test_UNSET():
     # for coverage
-    r = repr(UNSET)
\ No newline at end of file
+    r = repr(UNSET)
+    assert UNSET == UNSET
+    assert UNSET != None
\ No newline at end of file
